@@ -2,16 +2,17 @@ import asyncio
 import ctypes
 import functools
 import io
+import math
 import struct
 import winreg
 import zlib
 from collections import namedtuple
 from concurrent.futures.thread import ThreadPoolExecutor
+from ctypes import WinDLL
 from os import system as cmd
+from pathlib import Path
 from typing import Callable, Union
 from xml.etree import ElementTree
-from ctypes import WinDLL
-from pathlib import Path
 
 import appdirs
 from pymem.ptypes import RemotePointer
@@ -20,6 +21,13 @@ user32 = WinDLL("user32")
 XYZ = namedtuple("XYZ", "x, y, z")
 
 
+def _xyz_sub(self, other):
+    return math.dist((self.x, self.y), (other.x, other.y))
+
+
+XYZ.__sub__ = _xyz_sub
+
+
 # Modified from https://github.com/Gorialis/jishaku/blob/master/jishaku/functools.py#L19
 # This license covers the below function
 # MIT License
@@ -93,6 +101,36 @@ def quick_launch():
     start_wiz(location)
 
 
+def calculate_perfect_yaw(current_xyz: XYZ, target_xyz: XYZ) -> float:
+    """
+    Calculates the perfect yaw to reach target_xyz from current_xyz in a stright line
+    """
+    target_line = math.dist(
+        (current_xyz.x, current_xyz.y), (target_xyz.x, target_xyz.y)
+    )
+    origin_line = math.dist(
+        (current_xyz.x, current_xyz.y), (current_xyz.x, current_xyz.y - 1)
+    )
+    target_to_origin_line = math.dist(
+        (target_xyz.x, target_xyz.y), (current_xyz.x, current_xyz.y - 1)
+    )
+    # target_angle = math.cos(origin_line / target_line)
+    target_angle = math.acos(
+        (pow(target_line, 2) + pow(origin_line, 2) - pow(target_to_origin_line, 2))
+        / (2 * origin_line * target_line)
+    )
+
+    if target_xyz.x > current_xyz.x:
+        # outside
+        target_angle_degres = math.degrees(target_angle)
+        perfect_yaw = math.radians(360 - target_angle_degres)
+    else:
+        # inside
+        perfect_yaw = target_angle
+
+    return perfect_yaw
+
+
 def get_cache_folder() -> Path:
     app_name = "WizWalker"
     app_author = "StarrFox"
@@ -139,8 +177,8 @@ def get_all_wizard_handles() -> list:
         if target_class == class_name.value:
             handles.append(handle)
 
-        # iterate all windows
-        return False
+        # iterate all windows, (True)
+        return 1
 
     # https://docs.python.org/3/library/ctypes.html#callback-functions
     enumwindows_func_type = ctypes.WINFUNCTYPE(
@@ -251,14 +289,14 @@ def pharse_node_data(file_data: bytes) -> dict:
         if start == -1:
             break
 
-        entry = file_data[start:start + 48 + 2]
+        entry = file_data[start : start + 48 + 2]
 
-        cords_data = entry[16:16 + (4 * 3)]
+        cords_data = entry[16 : 16 + (4 * 3)]
         x = struct.unpack("<f", cords_data[0:4])[0]
         y = struct.unpack("<f", cords_data[4:8])[0]
         z = struct.unpack("<f", cords_data[8:12])[0]
 
-        node_num = entry[48:48 + 2]
+        node_num = entry[48 : 48 + 2]
         unpacked_num = struct.unpack("<H", node_num)[0]
 
         node_data[unpacked_num] = (x, y, z)
