@@ -1,11 +1,10 @@
-import pathlib
 import struct
 import zlib
 from collections import namedtuple
 
 import aiofiles
 
-from .utils import get_wiz_install, executor_function
+from .utils import executor_function, get_wiz_install
 
 wad_file_info = namedtuple("wad_file_info", "offset, size, is_zip, crc, unzipped_size")
 
@@ -16,9 +15,7 @@ class Wad:
             name += ".wad"
 
         self.name = name
-        self.file_path = (
-            get_wiz_install() / "Data" / "GameData" / self.name
-        )
+        self.file_path = get_wiz_install() / "Data" / "GameData" / self.name
         if not self.file_path.exists():
             raise RuntimeError(f"{self.name} not found.")
 
@@ -50,8 +47,6 @@ class Wad:
             if version >= 2:
                 fp.read(1)
 
-            total_journal_size = (4 + 4 + 4 + 1 + 4)
-
             for _ in range(file_num):
                 offset = struct.unpack("<l", fp.read(4))[0]
                 size = struct.unpack("<l", fp.read(4))[0]
@@ -62,7 +57,11 @@ class Wad:
                 name = (fp.read(name_length)).decode("utf-8")[:-1]
 
                 self.journal[name] = wad_file_info(
-                    offset=offset, size=size, is_zip=is_zip, crc=crc, unzipped_size=zsize,
+                    offset=offset,
+                    size=size,
+                    is_zip=is_zip,
+                    crc=crc,
+                    unzipped_size=zsize,
                 )
 
     async def get_file(self, name: str) -> bytes:
